==> roarplaylistd_0.1~rc6.orig.tar.gz: rpld-0.1rc6/rpld.h <==
//rpld.h:

/*
 *      Copyright (C) Philipp 'ph3-der-loewe' Schafft - 2009-2011
 *
 *  This file is part of RoarAudio PlayList Daemon,
 *  a playlist management daemon for RoarAudio.
 *  See README for details.
 *
 *  This file is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License version 3
 *  as published by the Free Software Foundation.
 *
 *  RoarAudio is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this software; see the file COPYING.  If not, write to
 *  the Free Software Foundation, 51 Franklin Street, Fifth Floor,
 *  Boston, MA 02110-1301, USA.
 *
 */

#ifndef _RPLD_RPLD_H_
#define _RPLD_RPLD_H_

#include <roaraudio.h>
#include <time.h>

#ifdef HAVE_LIB_UUID
#include <uuid/uuid.h>
#endif

#include "playlist.h"
#include "fformat.h"
#include "playback.h"
#include "proto_simple_vio.h"
#include "proto_simple.h"
#include "proto_mpd.h"
#include "client.h"
#include "network.h"
#include "store.h"
#include "autoqueue.h"
#include "yield.h"
#include "rpldslp.h"

#define MAX_PLAYLISTS 64

#define POINTER_DEFAULT      0
#define POINTER_CURRENT      1
#define POINTER_STARTUP      2
#define POINTER_TEMP         3

#define POINTER_NUM          4

struct rpld_playlist * g_queue, * g_history;
struct rpld_playlist * g_playlists[MAX_PLAYLISTS];

struct rpld_pointerarray {
 char * name;
 struct rpld_playlist_pointer * pointer;
} g_pointer[POINTER_NUM];

size_t       g_histsize;

volatile int g_alive;

#if defined(ROAR_HAVE_SETGID) && defined(ROAR_HAVE_IO_POSIX)
struct group   * g_grp;
#endif
#if defined(ROAR_HAVE_SETUID) && defined(ROAR_HAVE_IO_POSIX)
struct passwd  * g_pwd;
#endif

#ifdef ROAR_FT_SONAME_LIBROAR2
struct roar_plugincontainer * g_plugin_container;
#define PLUGIN_APPNAME    "rpld " ROAR_VSTR_ROARAUDIO
#define PLUGIN_ABIVERSION NULL
#endif

#endif

//ll

==> roarplaylistd_0.1.1.orig.tar.gz: rpld-0.1.1/rpld.h <==
//rpld.h:

/*
 *      Copyright (C) Philipp 'ph3-der-loewe' Schafft - 2009-2012
 *
 *  This file is part of RoarAudio PlayList Daemon,
 *  a playlist management daemon for RoarAudio.
 *  See README for details.
 *
 *  This file is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License version 3
 *  as published by the Free Software Foundation.
 *
 *  RoarAudio is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this software; see the file COPYING.  If not, write to
 *  the Free Software Foundation, 51 Franklin Street, Fifth Floor,
 *  Boston, MA 02110-1301, USA.
 *
 */

#ifndef _RPLD_RPLD_H_
#define _RPLD_RPLD_H_

#if defined(HAVE_LIB_XML2) && defined(ROAR_TARGET_WIN32)
// to work around the broken loader for DLLs disable use of libxml here.
#undef HAVE_LIB_XML2
#endif

#include <roaraudio.h>
#include <time.h>

#ifdef HAVE_LIB_UUID
#include <uuid/uuid.h>
#endif

#include "playlist.h"
#include "fformat.h"
#include "backend.h"
#include "playback.h"
#include "proto_simple_vio.h"
#include "proto_simple.h"
#include "proto_mpd.h"
#include "client.h"
#include "network.h"
#include "store.h"
#include "autoqueue.h"
#include "yield.h"
#include "rpldslp.h"
#include "pointer.h"
#include "plugin.h"

#define APPLICATION_NAME "RoarAudio PlayList daemon"

#if defined(ROAR_HAVE_SETGID) && defined(ROAR_HAVE_IO_POSIX)
extern struct group   * g_grp;
#endif
#if defined(ROAR_HAVE_SETUID) && defined(ROAR_HAVE_IO_POSIX)
extern struct passwd  * g_pwd;
#endif

void rpld_exit(void);

#endif

//ll
